@@ -27,53 +27,79 @@ along with Felupe.  If not, see <http://www.gnu.org/licenses/>.
 import numpy as np
 import pytest
 
-import felupe as fe
+import felupe as fem
 
 
 def test_line2():
-    line2 = fe.element.Line()
+    line2 = fem.element.Line()
 
     r = [-1]
 
     h = line2.function(r)
     dhdr = line2.gradient(r)
+    d2hdrdr = line2.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == -0.5)
+    assert np.all(d2hdrdr == 0.0)
 
     assert line2.shape == dhdr.shape
 
+    line2.plot(off_screen=True)
+
+
+def test_line_lagrange():
+    line6 = fem.element.ArbitraryOrderLagrange(order=5, dim=1)
+
+    r = [-1]
+
+    h = line6.function(r)
+    dhdr = line6.gradient(r)
+
+    assert np.isclose(h[0], 1)
+    assert np.isclose(dhdr[0, 0], -5.70833333)
+
+    assert line6.shape == dhdr.shape
+
+    line6.plot(off_screen=True)
+
 
 def test_quad0():
-    quad0 = fe.element.ConstantQuad()
+    quad0 = fem.element.ConstantQuad()
 
     r = [-1, -1]
 
     h = quad0.function(r)
     dhdr = quad0.gradient(r)
+    d2hdrdr = quad0.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == 0)
+    assert np.all(d2hdrdr == 0.0)
 
     assert quad0.shape == dhdr.shape
 
 
 def test_quad4():
-    quad4 = fe.element.Quad()
+    quad4 = fem.element.Quad()
 
     r = [-1, -1]
 
     h = quad4.function(r)
     dhdr = quad4.gradient(r)
+    d2hdrdr = quad4.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == -0.5)
+    assert d2hdrdr.shape == (4, 2, 2)
 
     assert quad4.shape == dhdr.shape
 
+    quad4.plot(off_screen=True)
+
 
 def test_quad8():
-    quad8 = fe.element.QuadraticQuad()
+    quad8 = fem.element.QuadraticQuad()
 
     r = [-1, -1]
 
@@ -87,7 +113,7 @@ def test_quad8():
 
 
 def test_quad9():
-    quad9 = fe.element.BiQuadraticQuad()
+    quad9 = fem.element.BiQuadraticQuad()
 
     r = [-1, -1]
 
@@ -101,35 +127,39 @@ def test_quad9():
 
 
 def test_hex0():
-    hex0 = fe.element.ConstantHexahedron()
+    hex0 = fem.element.ConstantHexahedron()
 
     r = [-1, -1, -1]
 
     h = hex0.function(r)
     dhdr = hex0.gradient(r)
+    d2hdrdr = hex0.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == 0)
+    assert np.all(d2hdrdr == 0)
 
     assert hex0.shape == dhdr.shape
 
 
 def test_hex8():
-    hex8 = fe.element.Hexahedron()
+    hex8 = fem.element.Hexahedron()
 
     r = [-1, -1, -1]
 
     h = hex8.function(r)
     dhdr = hex8.gradient(r)
+    d2hdrdr = hex8.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == -0.5)
+    assert d2hdrdr.shape == (8, 3, 3)
 
     assert hex8.shape == dhdr.shape
 
 
 def test_hex20():
-    hex20 = fe.element.QuadraticHexahedron()
+    hex20 = fem.element.QuadraticHexahedron()
 
     r = [-1, -1, -1]
 
@@ -141,9 +171,11 @@ def test_hex20():
 
     assert hex20.shape == dhdr.shape
 
+    hex20.plot(off_screen=True)
+
 
 def test_hex27():
-    hex27 = fe.element.TriQuadraticHexahedron()
+    hex27 = fem.element.TriQuadraticHexahedron()
 
     r = [-1, -1, -1]
 
@@ -155,23 +187,27 @@ def test_hex27():
 
     assert hex27.shape == dhdr.shape
 
+    hex27.plot(off_screen=True)
+
 
 def test_tri3():
-    tri3 = fe.element.Triangle()
+    tri3 = fem.element.Triangle()
 
     r = [0, 0]
 
     h = tri3.function(r)
     dhdr = tri3.gradient(r)
+    d2hdrdr = tri3.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == -1)
+    assert np.all(d2hdrdr == 0)
 
     assert tri3.shape == dhdr.shape
 
 
 def test_tri6():
-    tri6 = fe.element.QuadraticTriangle()
+    tri6 = fem.element.QuadraticTriangle()
 
     r = [0, 0]
 
@@ -185,36 +221,40 @@ def test_tri6():
 
 
 def test_tri_mini():
-    trim = fe.element.TriangleMINI()
+    trim = fem.element.TriangleMINI()
 
     r = [0, 0]
 
     h = trim.function(r)
     dhdr = trim.gradient(r)
+    d2hdrdr = trim.hessian(r)
 
     assert h[0] == 1
     assert h[-1] == 0  # check bubble
     assert np.all(dhdr[0] == -1)
+    assert d2hdrdr.shape == (4, 2, 2)
 
     assert trim.shape == dhdr.shape
 
 
 def test_tet4():
-    tet4 = fe.element.Tetra()
+    tet4 = fem.element.Tetra()
 
     r = [0, 0, 0]
 
     h = tet4.function(r)
     dhdr = tet4.gradient(r)
+    d2hdrdr = tet4.hessian(r)
 
     assert h[0] == 1
     assert np.all(dhdr[0] == -1)
+    assert np.all(d2hdrdr == 0)
 
     assert tet4.shape == dhdr.shape
 
 
 def test_tet10():
-    tet10 = fe.element.QuadraticTetra()
+    tet10 = fem.element.QuadraticTetra()
 
     r = [0, 0, 0]
 
@@ -228,23 +268,25 @@ def test_tet10():
 
 
 def test_tet_mini():
-    tetm = fe.element.TetraMINI()
+    tetm = fem.element.TetraMINI()
 
     r = [0, 0, 0]
 
     h = tetm.function(r)
     dhdr = tetm.gradient(r)
+    d2hdrdr = tetm.hessian(r)
 
     assert h[0] == 1
     assert h[-1] == 0  # check bubble
     assert np.all(dhdr[0] == -1)
+    assert d2hdrdr.shape == (5, 3, 3)
 
     assert tetm.shape == dhdr.shape
 
 
 def test_aol():
-    aol32 = fe.element.ArbitraryOrderLagrange(order=3, dim=2)
-    aol23 = fe.element.ArbitraryOrderLagrange(order=2, dim=3)
+    aol32 = fem.element.ArbitraryOrderLagrange(order=3, dim=2)
+    aol23 = fem.element.ArbitraryOrderLagrange(order=2, dim=3)
 
     r = [-1, -1]
 
@@ -265,6 +307,7 @@ def test_aol():
 
 if __name__ == "__main__":
     test_line2()
+    test_line_lagrange()
 
     test_quad0()
     test_quad4()
