@@ -4,14 +4,15 @@ Created on Sun Aug 21 00:27:38 2022
 
 @author: z0039mte
 """
+import os
 
 import numpy as np
+import pytest
 
 import felupe as fem
 
 
-def pre():
-
+def pre(SolidBodyForce=fem.SolidBodyForce):
     mesh = fem.Rectangle(n=2)
     region = fem.RegionQuad(mesh)
     field = fem.FieldsMixed(region, n=3, axisymmetric=True)
@@ -22,7 +23,7 @@ def pre():
 
     points = mesh.points[:, 0] == 1
     load = fem.PointLoad(field, points)
-    gravity = fem.SolidBodyGravity(field, [0, 0, 0], 0)
+    gravity = SolidBodyForce(field, [0, 0, 0], 0)
 
     region2 = fem.RegionQuadBoundary(mesh, mask=points, ensure_3d=True)
     field2 = fem.FieldContainer([fem.FieldAxisymmetric(region2, dim=2)])
@@ -42,30 +43,34 @@ def pre():
     return field, step
 
 
+def weather(i, j, res, outside):
+    assert outside == "rainy"
+
+
 def test_job():
-
-    field, step = pre()
+    field, step = pre(SolidBodyForce=fem.SolidBodyForce)
     job = fem.Job(steps=[step])
     job.evaluate()
-
     field, step = pre()
-    job = fem.Job(steps=[step])
-    job.evaluate()
+    job = fem.Job(steps=[step], callback=weather, outside="rainy")
+    job.evaluate(
+        parallel=True,
+        kwargs={"parallel": False},
+        verbose=0,
+    )
 
 
 def test_job_xdmf():
-
-    field, step = pre()
+    field, step = pre(SolidBodyForce=fem.SolidBodyGravity)
     job = fem.Job(steps=[step])
     job.evaluate()
 
     field, step = pre()
     job = fem.Job(steps=[step])
-    job.evaluate(filename="result.xdmf")
+    job.evaluate(filename="result.xdmf", parallel=True, verbose=2)
 
 
 def test_job_xdmf_global_field():
-
     field, step = pre()
     job = fem.Job(steps=[step])
     job.evaluate()
@@ -76,10 +81,21 @@ def test_job_xdmf_global_field():
 
 
 def test_curve():
-
     field, step = pre()
 
-    curve = fem.CharacteristicCurve(steps=[step], boundary=step.boundaries["move"])
+    curve = fem.CharacteristicCurve(
+        steps=[step],
+        boundary=step.boundaries["move"],
+        callback=weather,
+        outside="rainy",
+    )
+
+    with pytest.raises(ValueError):
+        curve.plot()
+
+    os.environ["FELUPE_VERBOSE"] = "true"
+
+    curve.evaluate()
     curve.plot(xaxis=0, yaxis=0)
     curve.plot(x=np.zeros((10, 2)), y=np.ones((10, 2)), xaxis=0, yaxis=0)
 
@@ -87,11 +103,12 @@ def test_curve():
     area = 1**2 * np.pi
     force = (stretch - 1 / stretch**2) * area
 
+    os.environ.pop("FELUPE_VERBOSE")
+
     assert np.allclose(np.array(curve.y)[:, 0], force, rtol=0.01)
 
 
 def test_curve2():
-
     field, step = pre()
 
     curve = fem.CharacteristicCurve(steps=[step], boundary=step.boundaries["move"])
@@ -106,14 +123,16 @@ def test_curve2():
 
 
 def test_curve_custom_items():
-
     field, step = pre()
 
     curve = fem.CharacteristicCurve(
         steps=[step], items=step.items, boundary=step.boundaries["move"]
     )
-    curve.plot(xaxis=0, yaxis=0, gradient=True)
-    curve.plot(x=np.zeros((10, 2)), y=np.ones((10, 2)), xaxis=0, yaxis=0)
+    curve.evaluate()
+    fig, ax = curve.plot(
+        xaxis=0, yaxis=0, gradient=True, swapaxes=True, xlabel="x", ylabel="y"
+    )
+    curve.plot(x=np.zeros((10, 2)), y=np.ones((10, 2)), xaxis=0, yaxis=0, ax=ax)
 
     stretch = 1 + np.array(curve.x)[:, 0]
     area = 1**2 * np.pi
@@ -123,7 +142,6 @@ def test_curve_custom_items():
 
 
 def test_empty():
-
     mesh = fem.Cube(n=2)
     region = fem.RegionHexahedron(mesh)
     field = fem.FieldsMixed(region, n=1)
@@ -137,7 +155,6 @@ def test_empty():
 
 
 def test_noramp():
-
     mesh = fem.Cube(n=2)
     region = fem.RegionHexahedron(mesh)
     field = fem.FieldsMixed(region, n=1)
